/* ggisyna - program to display sound graphically
   Copyright (C) 1997       Paul Francis Harrison
   Copyright (C) 1997-1998  Marcus Sundberg

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  675 Mass Ave, Cambridge, MA 02139, USA.

*/

/***************************************/
/*   For the incurably fiddle prone:   */

/* log2 of sample size */
#define m 8

/* overlap amount between samples. Set to 1 or 2 if you have a fast computer */
/* (not supported yet) */
#define overlap 0 

/* Brightness */
#define brightness 150

/* Sample frequency */
#define FREQUENCY 22050

/* CDROM device */
#define CDDEV "/dev/cdrom"

/* Sound device */
#define SNDDEV "/dev/dsp"

/* Mixer device */
#define MIXDEV "/dev/mixer"

/* The interval in which to change the mixersetting */
#define MIXINT 5

/***************************************/

#define attempt(x,y) if ((x) == -1) error(y)
#define attemptNoDie(x,y) if ((x) == -1) warning(y)

/**** *-sound.c **************************************/

#define SAMPLES (1<<m)
#define RECSIZE (1<<m-overlap)

#define SYNSND_NONE   (0)
#define SYNSND_LINE   (1)
#define SYNSND_MIC    (1<<1)
#define SYNSND_SYNTH  (1<<2)
#define SYNSND_CD     (1<<3)
#define SYNSND_STDIN  (1<<4)
#define SYNSND_MAIN   (1<<5)

int  sndSource(int source);
int  sndStart(int *pipes);
void mixUp(int source);
void mixDown(int source);

/**** *-cdrom.c **************************************/

int  cdGetTrackCount(void);
void cdPlay(int track);
void cdPause(void);
void cdResume(void);
void cdStop(void);
void cdGetStatus(int *track, int *paused, int *playing);

/**** *-gfx.c ***************************************/

extern int bpp;
void gfxOpen(void);
void gfxClose(void);
void setPalette(int i,int r,int g,int b);
void realizePalette(void);
int processUserInput(void); /* True == abort now */
void showOutput(void);

/**** main.c *****************************************/

extern int source;
extern int paused;
extern int stride;
extern unsigned char *backbuf;
extern int width, height;

void error(char *str);      /* Display error and exit */
void warning(char *str);    /* Display error */
void putIcon(int ox,int oy,int id,int channel);
void getNextFragment(void *data);

/**** core.c *****************************************/

void do_precalcs(void);
void syna_loop(void);
